@@ -15,6 +15,7 @@ import (
 	"github.com/prometheus/common/log"
 	op "github.com/tektoncd/operator/pkg/apis/operator/v1alpha1"
 	"github.com/tektoncd/operator/pkg/flag"
+	paddons "github.com/tektoncd/operator/pkg/utils/addons"
 	"github.com/tektoncd/operator/pkg/utils/transform"
 	"github.com/tektoncd/operator/pkg/utils/validate"
 	appsv1 "k8s.io/api/apps/v1"
@@ -129,6 +130,14 @@ func readAddons(mgr manager.Manager) (mf.Manifest, error) {
 		return mf.Manifest{}, err
 	}
 	addons = addons.Append(optionalResources)
+
+	// create all the pipeline dynamically
+	addonPipelineTemplates, err := paddons.CreatePipelines(flag.TemplatePath, mgr.GetClient())
+	if err != nil {
+		return mf.Manifest{}, err
+	}
+
+	addons = addons.Append(addonPipelineTemplates)
 	return addons, nil
 }
 
@@ -420,7 +429,7 @@ func (r *ReconcileConfig) applyAddons(req reconcile.Request, cfg *op.Config) (re
 	//add TaskProviderType label to ClusterTasks (community, redhat, certified)
 	addonImages := transform.ToLowerCaseKeys(imagesFromEnv(transform.AddonsImagePrefix))
 	addnTfrms := []mf.Transformer{
-		transform.InjectLabel(flag.LabelProviderType, flag.ProviderTypeCommunity, transform.Overwrite, "ClusterTask"),
+		transform.InjectLabel(flag.LabelProviderType, flag.ProviderTypeRedHat, transform.Overwrite, "ClusterTask"),
 		transform.TaskImages(addonImages),
 	}
 	newAddons, err := transformManifest(cfg, &r.addons, addnTfrms...)
